@@ -1,5 +1,4 @@
 import logging
-import time
 
 if __package__ == "":
     from tion_btle.tion import tion, TionException
@@ -41,24 +40,26 @@ class S3(tion):
             self._dummy_data = bytearray([0xb3, 0x10, 0x24, 0x14, 0x03, 0x00, 0x15, 0x14, 0x14, 0x8f, 0x00, 0x0c,
                                           0x0a, 0x00, 0x4b, 0x0a, 0x00, 0x33, 0x00, 0x5a])
 
+    @property
+    def pair_command(self) -> bytearray:
+        return self.create_command(self.command_PAIR)
+
+    @property
+    def get_status_command(self) -> bytearray:
+        return self.create_command(self.command_REQUEST_PARAMS)
+
     def __try_get_state(self) -> bytearray:
         response = self._btle.getServiceByUUID(self.uuid).getCharacteristics()[0].read()
         _LOGGER.debug("Response is %s", bytes(response).hex())
         return response
 
     def pair(self):
-        def get_pair_command() -> bytearray:
-            return self.create_command(self.command_PAIR)
         _LOGGER.setLevel("DEBUG")
         _LOGGER.debug("Pairing")
         _LOGGER.debug("Connecting")
         self._do_action(self._connect)
-        _LOGGER.debug("Collecting characteristic")
-        characteristic = self._btle.getServiceByUUID(self.uuid).getCharacteristics()[0]
-        _LOGGER.debug("Got characteristic %s for pairing", str(characteristic))
-        pair_command = get_pair_command()
-        _LOGGER.debug("Sending pair command %s to %s", bytes(pair_command).hex(), str(characteristic))
-        characteristic.write(bytes(get_pair_command()))
+        _LOGGER.debug("Sending pair command")
+        self._send_request(self.pair_command)
         _LOGGER.debug("Disconnecting")
         self._disconnect()
         _LOGGER.debug("Done!")
@@ -69,12 +70,8 @@ class S3(tion):
                           self.command_suffix])
 
     def _get_data_from_breezer(self) -> bytearray:
-        def get_status_command() -> bytearray:
-            return self.create_command(self.command_REQUEST_PARAMS)
-
         have_data_from_breezer: bool = False
-
-        self._do_action(self._try_write, request=get_status_command())
+        self._do_action(self._try_write, request=self.get_status_command)
 
         i = 0
         try:
@@ -140,5 +137,5 @@ class S3(tion):
                     self._encode_status(request["sound"]) << 3)
         return new_settings
 
-    def _send_request(self, request: bytearray) -> bytearray:
+    def _send_request(self, request: bytearray):
         self._do_action(self._try_write, request=request)
